%ifarch aarch64
%global bootcsv BOOTAA64.CSV
%endif

%ifarch x86_64
%global bootcsv BOOTX64.CSV
%endif

%global debug_package %{nil}
%undefine _debuginfo_subpackages

Summary:       First-stage UEFI bootloader
Name:          shim
Version:       15.7
Release:       2%{?dist}
License:       BSD
URL:           https://github.com/rhboot/shim
Source0:       %{url}/releases/download/%{version}/shim-%{version}.tar.bz2
Source1:       BOOTAA64.CSV
Source2:       BOOTX64.CSV

BuildRequires: elfutils-libelf-devel openssl-devel openssl git pesign gnu-efi gnu-efi-devel gcc
%ifarch aarch64
BuildRequires: binutils
%endif
Requires:      efi-filesystem mokutil
Provides:      bundled(openssl) = 1.0.2j
Provides:      shim-%{efi_arch} = %{version}-%{release}

ExclusiveArch:     x86_64 aarch64

%description
Initial UEFI bootloader that handles chaining to a trusted full bootloader under secure boot environments.

%prep
%autosetup -n shim-%{version} -p1 -S git
mkdir build-%{efi_arch}

%build
COMMITID=$(cat commit)
MAKEFLAGS="TOPDIR=.. -f ../Makefile COMMITID=${COMMITID} "
MAKEFLAGS+="EFIDIR=%{_vendor} PKGNAME=shim RELEASE=%{release} "
MAKEFLAGS+="ENABLE_HTTPBOOT=true ENABLE_SHIM_HASH=true "
MAKEFLAGS+="%{_smp_mflags}"

cd build-%{efi_arch}
make ${MAKEFLAGS} DEFAULT_LOADER='\\\\grub%{efi_arch}.efi' all

%install
COMMITID=$(cat commit)
MAKEFLAGS="TOPDIR=.. -f ../Makefile COMMITID=${COMMITID} "
MAKEFLAGS+="EFIDIR=%{_vendor} PKGNAME=shim RELEASE=%{release} "
MAKEFLAGS+="ENABLE_HTTPBOOT=true ENABLE_SHIM_HASH=true "

cd build-%{efi_arch}
make ${MAKEFLAGS} \
    DEFAULT_LOADER='\\\\grub%{efi_arch}.efi' \
    DESTDIR=%{buildroot} \
    install-debuginfo install-debugsource

install -D -d -m 0755 %{buildroot}/boot/
install -D -d -m 0700 %{buildroot}%{efi_esp_root}/
install -D -d -m 0700 %{buildroot}%{efi_esp_efi}/
install -D -d -m 0700 %{buildroot}%{efi_esp_dir}/
install -D -d -m 0700 %{buildroot}%{efi_esp_boot}/
install -m 0700 shim%{efi_arch}.efi   %{buildroot}%{efi_esp_dir}/shim%{efi_arch}.efi
install -m 0700 mm%{efi_arch}.efi     %{buildroot}%{efi_esp_dir}/mm%{efi_arch}.efi
install -m 0700 %{bootcsv}            %{buildroot}%{efi_esp_dir}/BOOT%{efi_arch_upper}.CSV
install -m 0700 shim%{efi_arch}.efi   %{buildroot}%{efi_esp_boot}/BOOT%{efi_arch_upper}.EFI
install -m 0700 fb%{efi_arch}.efi     %{buildroot}%{efi_esp_boot}/fb%{efi_arch}.efi

# install the debug symbols
install -d %{buildroot}/usr/lib/debug/%{efi_esp_dir}
install -m 644 fb%{efi_arch}.efi.debug %{buildroot}/usr/lib/debug/%{efi_esp_dir}
install -m 644 mm%{efi_arch}.efi.debug %{buildroot}/usr/lib/debug/%{efi_esp_dir}
install -m 644 shim%{efi_arch}.efi.debug %{buildroot}/usr/lib/debug/%{efi_esp_dir}

rm -rf %{buildroot}/usr/lib/debug
rm -rf %{buildroot}/usr/src/debug

%files
%license COPYRIGHT
%{efi_esp_dir}/*%{efi_arch}*.efi
%{efi_esp_dir}/BOOT%{efi_arch_upper}.CSV
%{efi_esp_boot}/*%{efi_arch}.efi
%{efi_esp_boot}/*%{efi_arch_upper}.EFI

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.7-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 01 2023 kianli <kianli@tencent.com> - 15.7-1
- Upgrade to 15.7

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.6-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 15.6-4
- Rebuilt for OpenCloudOS Stream 23

* Tue Feb 7 2023 Shuo Wang <abushwang@tencent.com> - 15.6-3
- remove debuginfo and debugsource

* Wed Jan 11 2023 Shuo Wang <abushwang@tencent.com> - 15.6-2
- source build shim

* Tue Sep 20 2022 Shuo Wang <abushwang@tencent.com> - 15.6-1
- initial build

